
attribute vec4 a_position;
attribute vec2 a_texCoord;
attribute vec4 a_color;
attribute vec3 a_glow;
attribute float a_grayscale;
attribute float a_texUnit;

#ifdef GL_ES
varying mediump vec2 v_texCoord;
varying lowp float v_texUnit;
#else
varying vec2 v_texCoord;
varying float v_texUnit;
#endif

// Fast and accurate sine and cosine approximations
// http://devmaster.net/posts/9648/fast-and-accurate-sine-cosine
float myFastSine(float x)
{
    const float pi = 3.14159;
    const float TwoPi = 2.0 * pi;
    const float OneOverTwoPi = 1.0 / TwoPi;
    const float B = 4.0 / pi;
    const float C = -4.0 / (pi * pi);
    
    x = (x + pi) * OneOverTwoPi;
    x = fract(x);
    x = (x * TwoPi) - pi;
    
    float y = B * x + C * x * abs(x);
    const float P = 0.225;
    y = P * (y * abs(y) - y) + y;   // Q * y + P * y * abs(y)
    
    return y;
}

void main()
{
    vec4 position = CC_MVPMatrix * a_position;
    float sinAdjustmentX = CC_MVMatrix[0][0] * (myFastSine(-CC_CosTime.x + a_position.x / 64.0)) * a_color.r;
    float sinAdjustmentY =  CC_MVMatrix[0][0] * (myFastSine(-CC_CosTime.y + a_position.y / 64.0)) * a_color.g;
    gl_Position = vec4(position.x + sinAdjustmentX, position.y + sinAdjustmentY, position.z, position.a);
    v_texCoord = a_texCoord;
    v_texUnit = a_texUnit;
}